#  Copyright (c) 2020 Cloudera, Inc. All rights reserved.
#
import ldap
from ldappool import ConnectionManager

RUNNING_IN_CLUSTER = False
LAST_AGREEMENTS = {}
ldap.set_option(ldap.OPT_X_TLS_REQUIRE_CERT, ldap.OPT_X_TLS_NEVER)
cm = ConnectionManager('ldap://localhost')


def _get_replication_agreements():
    global RUNNING_IN_CLUSTER
    global LAST_AGREEMENTS

    try:
        with cm.connection('', '') as lconn:
            agreements = lconn.search_s(
                'cn=config', ldap.SCOPE_SUBTREE,
                'objectclass=nsds5replicationagreement')
            RUNNING_IN_CLUSTER = len(agreements) > 0
            LAST_AGREEMENTS = agreements
            return agreements
    except ldap.SERVER_DOWN:
        return LAST_AGREEMENTS
    except AttributeError as error:
        return LAST_AGREEMENTS
    except Exception as exception:
        return LAST_AGREEMENTS


def get_replication_agreements():
    return _get_replication_agreements()


def is_clustered():
    global RUNNING_IN_CLUSTER
    _get_replication_agreements()
    return RUNNING_IN_CLUSTER
