# Copyright (c) 2020 Cloudera, Inc.
#
from enum import Enum

from ipahealthagent.main.utils import get_fqdn


class Status(str, Enum):
    """
    HEALTHY just means that the checks and host are all healthy
    DEGRADED means that something is wrong, but not bad enough to bring things
        down so overall the service is still running.
    UNHEALTHY means some critical component is down and may no longer be able to
         provide service
    ERROR means something went wrong with the code and the node should be
      treated as unhealthy.
    """
    HEALTHY = 'HEALTHY'
    DEGRADED = 'DEGRADED'
    UNHEALTHY = 'UNHEALTHY'
    ERROR = 'ERROR'

    def __str__(self):
        return self.name


class CheckResult(dict):
    def __init__(self):
        super(CheckResult, self).__init__()
        self['host'] = get_fqdn()
        self['status'] = Status.HEALTHY
        self['checks'] = []
        self['plugin_stat'] = []

    @property
    def host(self):
        return self['host']

    @host.setter
    def host(self, value):
        self['host'] = value

    @property
    def status(self):
        return self['status']

    @status.setter
    def status(self, value):
        self['status'] = value

    @property
    def checks(self):
        return self['checks']

    @checks.setter
    def checks(self, value):
        self['checks'] = value

    @property
    def plugin_stat(self):
        return self['plugin_stat']

    @plugin_stat.setter
    def plugin_stat(self, value):
        self['plugin_stat'] = value


class CheckEntry(dict):
    def __init__(self, name):
        super(CheckEntry, self).__init__()
        self['plugin'] = name
        self['status'] = Status.HEALTHY
        self['check_id'] = ""
        self['detail'] = {}

    @property
    def plugin(self):
        return self['plugin']

    @plugin.setter
    def plugin(self, value):
        self['plugin'] = value

    @property
    def status(self):
        return self['status']

    @status.setter
    def status(self, value):
        self['status'] = value

    @property
    def check_id(self):
        return self['check_id']

    @check_id.setter
    def check_id(self, value):
        self['check_id'] = value

    @property
    def detail(self):
        return self['detail']

    @detail.setter
    def detail(self, value):
        self['detail'] = value


class ClusterCheckResult(dict):
    def __init__(self):
        super(ClusterCheckResult, self).__init__()
        self['host'] = get_fqdn()
        self['status'] = Status.HEALTHY
        self['replicas'] = []
        self['plugin_stat'] = []

    @property
    def host(self):
        return self['host']

    @host.setter
    def host(self, value):
        self['host'] = value

    @property
    def status(self):
        return self['status']

    @status.setter
    def status(self, value):
        self['status'] = value

    @property
    def replicas(self):
        return self['replicas']

    @replicas.setter
    def replicas(self, value):
        self['replicas'] = value

    @property
    def plugin_stat(self):
        return self['plugin_stat']

    @plugin_stat.setter
    def plugin_stat(self, value):
        self['plugin_stat'] = value


class PluginCheckResult(dict):
    def __init__(self, name):
        super(PluginCheckResult, self).__init__()
        self['host'] = get_fqdn()
        self['status'] = Status.HEALTHY
        self['plugin'] = name
        self['detail'] = {}
        self['response_time'] = 0

    @property
    def host(self):
        return self['host']

    @host.setter
    def host(self, value):
        self['host'] = value

    @property
    def status(self):
        return self['status']

    @status.setter
    def status(self, value):
        self['status'] = value

    @property
    def plugin(self):
        return self['plugin']

    @plugin.setter
    def plugin(self, value):
        self['plugin'] = value

    @property
    def detail(self):
        return self['detail']

    @detail.setter
    def detail(self, value):
        self['detail'] = value

    @property
    def response_time(self):
        return self['response_time']

    @response_time.setter
    def response_time(self, value):
        self['response_time'] = value
