# Copyright (c) 2020 Cloudera, Inc.
#
import importlib.machinery
import inspect
import os
import socket

from ipahealthagent import logging

PluginFolder = "ipahealthagent/plugins"
MainModule = "__init__"

loaded_plugins = []

LOG = logging.getLogger(__name__)


def get_fqdn():
    return socket.getfqdn()


def get_plugins():
    plugins = []
    files = os.listdir(PluginFolder)
    for file in files:
        fullpath = os.path.join(PluginFolder, file)
        if os.path.isdir(fullpath):
            LOG.info("Plugin path: " + fullpath)
            plugins.append({"name": file,
                            "metadata": importlib.machinery.PathFinder.find_spec(MainModule,
                                                        [fullpath])})
    LOG.info("Plugins: " + str(plugins))
    return plugins


def get_loaded_plugins():
    return loaded_plugins


def check_config(m_time, module):
    statbuf = os.stat(inspect.getfile(module))
    if statbuf.st_mtime != m_time:
        importlib.reload(module)
        m_time = statbuf.st_mtime
    return m_time
