# Copyright (c) 2020 Cloudera, Inc.
#
# __init__.py: Plugin to check backups

import os

from ipahealthagent import logging
from ipahealthagent.main.result import Status, CheckEntry
from ipahealthagent.main.utils import check_config
from ipahealthagent.plugins.backup_check import config

name = 'BACKUP_CHECK'
config_mtime = None
LOG = logging.getLogger(name)


def run(is_part_of_cluster=False):
    global config_mtime
    config_mtime = check_config(config_mtime, config)
    checks = []
    check = CheckEntry(name)
    checks.append(check)
    check.check_id = "backup"

    try:
        if os.path.exists(config.Config.BACKUP_FILE):
            with open(config.Config.BACKUP_FILE, 'r') as backup_file:
                line = backup_file.readline()
                if not line:
                    check.detail.update({'Error': 'No data in file.'})
                    check.status = Status.ERROR
                elif 'Backup succeeded' in line:
                    check.detail.update({'Status': line})
                else:
                    check.detail.update({'Status': line})
                    check.status = Status.DEGRADED
    except Exception as e:
        LOG.error('Failed backup check', exc_info=True)
        check.detail.update({'Exception': str(e)})
        check.status = Status.ERROR

    return checks
