# Copyright (c) 2024 Cloudera, Inc.
#
# __init__.py: Plugin to check cluster replication

import subprocess

from ipahealthagent import logging
from ipahealthagent.main.result import Status, CheckEntry
from ipahealthagent.main.utils import check_config
from ipahealthagent.plugins.backup_check import config

import yaml

name = 'KRB5_CHECK'
LOG = logging.getLogger(name)
config_mtime = None

plugin_type = 'HEALTH_CHECK'


def run(is_part_of_cluster=False):
    global config_mtime
    config_mtime = check_config(config_mtime, config)
    checks = []

    with open('/opt/ipahealthagent/config.yaml', 'r') as configfile:
        cfg = yaml.full_load(configfile)

    realm = cfg["realm"]
    hostname = cfg["hostname"]

    command = f"kinit -V -S krbtgt/{realm} -k -t /etc/krb5.keytab host/{hostname} -c MEMORY:tmp_cache"

    check = CheckEntry(name)
    checks.append(check)
    check.check_id = "krb5"

    try:
        result = subprocess.run(command, shell=True, capture_output=True, text=True)

        if result.returncode == 0:
            check.detail.update({'Status': 'kinit with host key successful.'})
        else:
            check.status = Status.UNHEALTHY
            check.detail.update({'Status': 'kinit with host key failed.'})

    except Exception as e:
        check.status = Status.UNHEALTHY
        check.detail.update({'Status': 'kinit with host key failed.'})

    return checks
