# Copyright (c) 2024 Cloudera, Inc.
#
# __init__.py: Plugin to check cluster replication

import re
import subprocess

from ipahealthagent import logging
from ipahealthagent.main.result import Status, CheckEntry, CheckResult
from ipahealthagent.main.utils import check_config
from ipahealthagent.plugins.backup_check import config

name = 'LDAP_CHECK'
LOG = logging.getLogger(name)
config_mtime = None

plugin_type = 'HEALTH_CHECK'


def run(is_part_of_cluster=False):
    global config_mtime
    config_mtime = check_config(config_mtime, config)
    checks = []

    hostname = "localhost"
    command = f"ldapsearch -x -H ldap://{hostname} -b '' -s base '(objectclass=*)'"

    check = CheckEntry(name)
    checks.append(check)
    check.check_id = "ldap"

    try:
        result = subprocess.run(command, shell=True, capture_output=True, text=True)

        if result.returncode == 0:
            if "result: 0 Success" in result.stdout:
                check.detail.update({'Status': 'LDAP search successful.'})
        else:
            check.status = Status.UNHEALTHY
            check.detail.update({'Status': 'LDAP search not working.'})

    except Exception as e:
        check.status = Status.UNHEALTHY
        check.detail.update({'Status': 'LDAP search not working.'})

    return checks
