# Copyright (c) 2020 Cloudera, Inc.
#
# __init__.py: Plugin to check ports listening
import re
import subprocess

from ipahealthagent import logging
from ipahealthagent.main.result import Status, CheckEntry
from ipahealthagent.main.utils import check_config
from ipahealthagent.plugins.port_check import config

name = 'PORT_CHECK'
config_mtime = None
LOG = logging.getLogger(name)


def run(is_part_of_cluster=False):
    global config_mtime
    config_mtime = check_config(config_mtime, config)
    checks = []

    port_list = config.Config.ports[:]
    if is_part_of_cluster:
        port_list += config.Config.cluster_ports

    p = subprocess.Popen(["ss", "-lntu"], stdout=subprocess.PIPE)
    tcpdata = p.stdout.read()

    for entry in tcpdata.splitlines():
        local_address = re.split(r'\s+', str(entry))[4]
        try:
            addr_str, port_str = local_address.rsplit(':', 1)
            port = int(port_str)
            if port in port_list:
                check = CheckEntry(name)
                checks.append(check)
                check.check_id = str(port)
                check.detail.update({'listening': addr_str})
                port_list.remove(port)
        except ValueError:
            continue

    for port in port_list:
        check = CheckEntry(name)
        checks.append(check)
        check.status = Status.UNHEALTHY
        check.check_id = str(port)
        check.detail.update({'Status': 'Not listening.'})

    return checks
