# Copyright (c) 2020 Cloudera, Inc.
#
# __init__.py: Plugin to check cluster replication

import requests
from requests import RequestException

from ipahealthagent import Config
from ipahealthagent import logging
from ipahealthagent.main.result import Status, CheckEntry, CheckResult
from ipahealthagent.main.utils import check_config
from ipahealthagent.plugins.backup_check import config
from ipahealthagent.main.cluster import get_replication_agreements, is_clustered

name = 'REPLICATION_CHECK'
LOG = logging.getLogger(name)
config_mtime = None

plugin_type = 'CLUSTER_HEALTH'


def run(is_part_of_cluster=False):
    global config_mtime
    config_mtime = check_config(config_mtime, config)
    results = []
    try:
        if is_part_of_cluster:
            queryresults = get_replication_agreements()
            for items in queryresults:
                result = CheckResult()
                results.append(result)

                data = items[1]
                replication_host = data['nsDS5ReplicaHost'][0]
                result.host = replication_host

                check = CheckEntry(name)
                result.checks.append(check)
                check.check_id = 'replicationAgreements'
                check.detail.update(
                    {"last_update": data['nsds5replicaLastUpdateEnd'][0],
                     "message": data['nsds5replicaLastUpdateStatus'][0]})
                if data['nsds5replicaLastUpdateStatus'][
                    0] != 'Error (0) Replica acquired ' \
                          'successfully: Incremental update succeeded':
                    check.status = Status.UNHEALTHY

                ping_check = CheckEntry(name + "-ping")
                result.checks.append(ping_check)
                ping_check.check_id = 'ping'

                try:
                    ping = requests.get(
                        'https://' + replication_host + ':' + str(
                            Config.PORT) + '/ping',
                        verify=False, timeout=0.3)
                    ping_check.detail.update({str(ping.status_code): ping.text})
                    if ping.status_code != 200 or ping.text != 'pong':
                        ping_check.status = Status.UNHEALTHY
                except requests.exceptions.ConnectionError as e2:
                    LOG.warning(str(e2))
                    ping_check.status = Status.UNHEALTHY
                    ping_check.detail.update({'Exception': str(e2)})
                except RequestException as e:
                    LOG.error(str(e))
                    ping_check.status = Status.ERROR
                    ping_check.detail.update({'Exception': str(e)})
    except Exception as e:
        LOG.error('Replication check failed', exc_info=True)
        result = CheckResult()
        results.append(result)
        check = CheckEntry(name)
        result.checks.append(check)
        check.check_id = 'replicationAgreements'
        check.status = Status.ERROR
        check.detail.update({'Exception': str(e)})

    return results
