# Copyright (c) 2024 Cloudera, Inc.
#
# __init__.py: Plugin to check cluster replication

import requests
from requests import RequestException

from ipahealthagent import logging
from ipahealthagent.main.result import Status, CheckEntry, CheckResult
from ipahealthagent.main.utils import check_config
from ipahealthagent.plugins.backup_check import config

import yaml

name = 'WEBSERVICE_CHECK'
LOG = logging.getLogger(name)
config_mtime = None

plugin_type = 'HEALTH_CHECK'


def run(is_part_of_cluster=False):
    global config_mtime
    config_mtime = check_config(config_mtime, config)
    results = []
    result = CheckResult()
    results.append(result)

    result.host = "localhost"

    ui_check = CheckEntry(name)
    result.checks.append(ui_check)
    ui_check.check_id = 'webService'

    with open('/opt/ipahealthagent/config.yaml', 'r') as configfile:
        cfg = yaml.full_load(configfile)
    cfgTimeout = int(cfg["timeout"])

    try:
        resp = requests.get('https://localhost/ipa/ui',verify=False, timeout=cfgTimeout)
        ui_check.detail.update({str(resp.status_code): resp.text})
        if resp.status_code != 200:
            ui_check.status = Status.UNHEALTHY
    except requests.exceptions.ConnectionError as e2:
        LOG.warning(str(e2))
        ui_check.status = Status.UNHEALTHY
        ui_check.detail.update({'Exception': str(e2)})
    except RequestException as e:
        LOG.error(str(e))
        ui_check.status = Status.UNHEALTHY
        ui_check.detail.update({'Exception': str(e)})

    return results
